@@ -87,6 +87,7 @@ sub test_throw {
         $self->assert_equals(__PACKAGE__ . '::test_throw', $obj3->{caller_stack}->[3]->[3]);
         $self->assert_equals(ref $self, ref $obj3->{caller_stack}->[3]->[8]);
 
+	# Rethrow with overriden class
         {
             package Exception::Base::throw::Test1;
             our @ISA = ('Exception::Base');
@@ -101,6 +102,38 @@ sub test_throw {
         $self->assert_equals('New throw', $obj4->{message});
         $self->assert_equals(__PACKAGE__ . '::test_throw', $obj4->{caller_stack}->[3]->[3]);
         $self->assert_equals(ref $self, ref $obj4->{caller_stack}->[3]->[8]);
+
+	# Throw based on last eval error (with \n)
+        eval {
+	    die "Died\n";
+        };
+	my $e5 = $@;
+        $self->assert_not_equals('', $e5);
+	eval {
+	    Exception::Base->throw($e5);
+	};
+        my $obj5 = $@;
+        $self->assert_not_null($obj5);
+        $self->assert($obj5->isa('Exception::Base'));
+        $self->assert_equals('Died', $obj5->{message});
+        $self->assert_equals(__PACKAGE__ . '::test_throw', $obj5->{caller_stack}->[3]->[3]);
+        $self->assert_equals(ref $self, ref $obj5->{caller_stack}->[3]->[8]);
+
+	# Throw based on last eval error (without \n)
+        eval {
+	    die "Died";
+        };
+	my $e6 = $@;
+        $self->assert_not_equals('', $e6);
+	eval {
+	    Exception::Base->throw($e6);
+	};
+        my $obj6 = $@;
+        $self->assert_not_null($obj6);
+        $self->assert($obj6->isa('Exception::Base'));
+        $self->assert_equals('Died', $obj6->{message});
+        $self->assert_equals(__PACKAGE__ . '::test_throw', $obj6->{caller_stack}->[3]->[3]);
+        $self->assert_equals(ref $self, ref $obj6->{caller_stack}->[3]->[8]);
     };
     die "$@" if $@;
 }
